#
# spec file for package python-mrcfile
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-mrcfile
Version:        1.5.4
Release:        1.1
Summary:        MRC file I/O library
License:        BSD-3-Clause
URL:            https://github.com/ccpem/mrcfile
Source:         https://github.com/ccpem/mrcfile/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module numpy >= 1.16.0}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
Requires:       python-numpy >= 1.16.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
A Python implementation of the MRC2014 file format, which
is used in structural biology to store image and volume data.

%prep
%autosetup -p1 -n mrcfile-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/mrcfile-header
%python_clone -a %{buildroot}%{_bindir}/mrcfile-validate
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_data_is_not_copied_unnecessarily: https://github.com/ccpem/mrcfile/issues/49
skip='test_data_is_not_copied_unnecessarily'
# test_data_is_not_read_if_dimensions_are_too_huge": https://github.com/ccpem/mrcfile/issues/53
skip="$skip or test_data_is_not_read_if_dimensions_are_too_huge"
%pytest -v -k "not ($skip)"

%post
%python_install_alternative mrcfile-header mrcfile-validate

%postun
%python_uninstall_alternative mrcfile-header

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%python_alternative %{_bindir}/mrcfile-header
%python_alternative %{_bindir}/mrcfile-validate
%{python_sitelib}/mrcfile*

%changelog
* Mon Mar 10 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.5.4
  * Fix rare bug in mmap alignment with certain extended header sizes
  * Add test and documentation code to source distribution
  * Add support for Python 3.13 and numpy 2.1 & 2.2
- Switch build system from setuptools to pyproject.toml
  * Add python-pip and python-wheel to BuildRequires
  * Replace %%python_build with %%pyproject_wheel
  * Replace %%python_install with %%pyproject_install
- Use Python 3.11 on SLE-15 by default
* Mon Sep  9 2024 Markéta Machová <mmachova@suse.com>
- update to 1.5.3
  * Add support for numpy 2.0
  * Fix opening of large files in numpy 2.0
  * Validate header statistics only if they are set
* Mon Jan 22 2024 Dirk Müller <dmueller@suse.com>
- update to 1.5.0:
  * Add new 'indexed_extended_header' attribute to access the
    indexed part of the extended header if it exists
  * Add support for numpy 1.24, 1.25 and 1.26 and Python 3.12
* Tue May  2 2023 Jan Engelhardt <jengelh@inai.de>
- Update description
* Tue May  2 2023 pgajdos@suse.com
- initial version 1.4.3, required by python-GridDataFormats
